
============  ==================  ====  ========  =====  ==================  ==============  ==================
name          value               unit  type      valid  default             code            description
============  ==================  ====  ========  =====  ==================  ==============  ==================
description   UNKNOWN                   string    None   UNKNOWN             B               Description of
                                                                                             this product
type          BaseProduct               string    None   BaseProduct         B               Product Type
                                                                                             identification.
                                                                                             Name of class or
                                                                                             CARD.
level         ALL                       string    None   ALL                 B               Product level.
creator       UNKNOWN                   string    None   UNKNOWN             B               Generator of this
                                                                                             product.
creationDate  1958-01-01T00:00:0        finetime  None   1958-01-01T00:00:0  %Y-% m-%d T%H:  Creation date of
              0.000000 0                                 0.000000 0          %M:% S.%f       this product
rootCause     UNKNOWN                   string    None   UNKNOWN             B               Reason of this run
                                                                                             of  pipeline.
version       0.8                       string    None   0.8                 B               Version of product
FORMATV       1.6.0.11                  string    None   1.6.0.11            B               Version of product
                                                                                             schema and
                                                                                             revision
listeners     <No listener>
============  ==================  ====  ========  =====  ==================  ==============  ==================